@@ -1,7 +1,8 @@
+"""API 基类异常"""
+
+
 class ApiException(Exception):
-    """
-    API 基类异常。
-    """
+    """API 基类异常。"""
 
     def __init__(self, msg: str = "出现了错误，但是未说明具体原因"):
         super().__init__(msg)
