@@ -2,7 +2,7 @@
 
 import random
 
-from .song import query_by_id
+from .song import query_song
 from .utils.network import Api
 from .utils.utils import get_api
 
@@ -24,9 +24,6 @@ class MV:
         """
         self.vid = vid
 
-    def __repr__(self) -> str:
-        return f"MV(vid={self.vid})"
-
     async def get_detail(self) -> dict:
         """获取 MV 详细信息
 
@@ -72,7 +69,7 @@ class MV:
             "required": ["related_songs"],
         }
         song_id = (await Api(**API["detail"]).update_params(**param).result)[self.vid]["related_songs"]
-        return await query_by_id(song_id)
+        return await query_song(song_id)
 
     async def get_url(self) -> dict:
         """获取 MV 播放链接
