@@ -1,7 +1,6 @@
 import pytest
 
 from qqmusic_api.singer import (
-    Song,
     TabType,
 )
 
@@ -13,11 +12,6 @@ async def test_get_info(singer):
     assert info
 
 
-async def test_get_fans_num(singer):
-    fans_num = await singer.get_fans_num()
-    assert fans_num
-
-
 async def test_get_tab_detail(singer):
     tab_type = TabType.WIKI
     tab_detail = await singer.get_tab_detail(tab_type)
@@ -32,4 +26,3 @@ async def test_get_wiki(singer):
 async def test_get_song(singer):
     songs = await singer.get_song()
     assert isinstance(songs, list)
-    assert all(isinstance(song, Song) for song in songs)
